.. _ref_user_guide:

User guide
##########

This section outlines the fundamental configurations of the Ansys Sphinx theme and how to integrate
third-party extensions with this theme to customize your documentation.

.. grid:: 1 1 2 2
   :gutter: 2
   :padding: 2
   :margin: 2

   .. grid-item-card:: :octicon:`tools` :ref:`ref_user_guide_configuration`
      :link: user-guide/configuration
      :link-type: doc

      Configure the Ansys Sphinx Theme

   .. grid-item-card:: :octicon:`gear` :ref:`ref_user_guide_html_theme`
      :link: user-guide/options
      :link-type: doc

      Set theme options

   .. grid-item-card:: :octicon:`link` :ref:`ref_user_guide_extension`
      :link: user-guide/linkcode
      :link-type: doc

      See how to use the ``linkcode`` extension with the Ansys Sphinx Theme.

   .. grid-item-card:: :octicon:`cross-reference` :ref:`ref_user_guide_autoapi`
      :link: user-guide/autoapi
      :link-type: doc

      See how to use Sphinx AutoAPI with the Ansys Sphinx Theme.


.. toctree::
   :maxdepth: 2
   :hidden:
   :caption: Ansys Sphinx Theme configuration

   user-guide/configuration
   user-guide/pdf

.. toctree::
    :maxdepth: 2
    :hidden:
    :caption: Theme options

    user-guide/options

.. toctree::
    :maxdepth: 2
    :hidden:
    :caption: Ansys Sphinx Theme extensions

    user-guide/linkcode
    user-guide/autoapi

